
# Type: sequence variant_id




URI: [biolink:sequence_variant_id](https://w3id.org/biolink/vocab/sequence_variant_id)


## Domain and Range

[SequenceVariant](SequenceVariant.md) ->  <sub>REQ</sub> [IdentifierType](types/IdentifierType.md)

## Parents

 *  is_a: [id](id.md)

## Children


## Used by

 * [SequenceVariant](SequenceVariant.md)
